@@ -57,7 +57,7 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_H5Dget_space", (DL_FUNC) &_H5Dget_space, 1},
   {"_H5Dget_storage_size", (DL_FUNC) &_H5Dget_storage_size, 1},
   {"_H5Dread", (DL_FUNC) &_H5Dread, 8},
-  {"_H5Dwrite", (DL_FUNC) &_H5Dwrite, 5},
+  {"_H5Dwrite", (DL_FUNC) &_H5Dwrite, 6},
   {"_H5Dset_extent", (DL_FUNC) &_H5Dset_extent, 2},
   {"_H5Fcreate", (DL_FUNC) &_H5Fcreate, 4},
   {"_H5Fopen", (DL_FUNC) &_H5Fopen, 3},
@@ -129,6 +129,8 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_H5Tget_precision", (DL_FUNC) &_H5Tget_precision, 1},
   {"_H5Tset_offset", (DL_FUNC) &_H5Tset_offset, 2},
   {"_H5Tget_offset", (DL_FUNC) &_H5Tget_offset, 1},
+  {"_H5Tenum_create", (DL_FUNC) &_H5Tenum_create, 1},
+  {"_H5Tenum_insert", (DL_FUNC) &_H5Tenum_insert, 3},
   {"_H5Pcreate", (DL_FUNC) &_H5Pcreate, 1},
   {"_H5Pget_class", (DL_FUNC) &_H5Pget_class, 1},
   {"_H5Pcopy", (DL_FUNC) &_H5Pcopy, 1},
@@ -234,7 +236,7 @@ static R_CallMethodDef libraryRCalls[] = {
   {"_H5Pget_fill_time", (DL_FUNC) &_H5Pget_fill_time, 1},
   {"_H5Pset_alloc_time", (DL_FUNC) &_H5Pset_alloc_time, 2},
   {"_H5Pget_alloc_time", (DL_FUNC) &_H5Pget_alloc_time, 1},
-  /* {"_H5Pset_filter", (DL_FUNC) &_H5Pset_filter, 5}, */
+  {"_H5Pset_filter", (DL_FUNC) &_H5Pset_filter, 4},
   {"_H5Pall_filters_avail", (DL_FUNC) &_H5Pall_filters_avail, 1},
   {"_H5Pget_nfilters", (DL_FUNC) &_H5Pget_nfilters, 1},
   /* {"_H5Pget_filter1", (DL_FUNC) &_H5Pget_filter1, 7}, */
@@ -342,12 +344,12 @@ void R_init_rhdf5 (DllInfo * winDll) {
 
 SEXP HID_2_CHARSXP(hid_t hid) {
     char tmp_string[21]; 
-    sprintf(tmp_string, "%lld", (long long) hid);
+    snprintf(tmp_string, 21, "%lld", (long long) hid);
     return(mkChar(tmp_string));
 }
 
 SEXP HID_2_STRSXP(hid_t hid) {
     char tmp_string[21]; 
-    sprintf(tmp_string, "%lld", (long long) hid);
+    snprintf(tmp_string, 21, "%lld", (long long) hid);
     return(mkString(tmp_string));
 }
